@@ -305,15 +305,14 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
         if ms_drivers.match(driver) and os.name == 'nt':
             cstr_parts['MARS_Connection'] = 'yes'
-        # print('cstr_parts--> ', cstr_parts)
+        #print('cstr_parts--> ', cstr_parts)
         connstr = encode_connection_string(cstr_parts)
-        print('connection String--> ', connstr)
         # extra_params are glued on the end of the string without encoding,
         # so it's up to the settings writer to make sure they're appropriate -
         # use encode_connection_string if constructing from external input.
-        if options.get('extra_params', None):
-            connstr += ';' + options['extra_params']
-
+        # if options.get('extra_params', None):
+        #     connstr += ';' + options['extra_params']
+        print('connection String--> ', connstr)
         unicode_results = options.get('unicode_results', False)
         timeout = options.get('connection_timeout', 0)
         retries = options.get('connection_retries', 5)
@@ -325,7 +324,10 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         need_to_retry = False
         while conn is None:
             try:
-                conn = Database.connect(connstr)
+                print('retry count: ', retry_count)
+                conn = Database.connect(connstr,
+                                        unicode_results=unicode_results,
+                                        timeout=timeout)
             except Exception as e:
                 print('Error occurred during connect: ', e)
                 for error_number in self._transient_error_numbers:
